==> mule-runtime-tooling-client-4.5.0-rc1-sources.jar: org/mule/tooling/client/internal/InternalExtensionModelService.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.tooling.client.internal;

import org.mule.maven.client.api.model.BundleDescriptor;
import org.mule.runtime.api.meta.model.ExtensionModel;
import org.mule.runtime.module.artifact.api.classloader.ArtifactClassLoader;
import org.mule.runtime.module.artifact.api.descriptor.ArtifactPluginDescriptor;

import java.io.File;
import java.util.List;
import java.util.Optional;

public interface InternalExtensionModelService {

  /**
   * Loads the {@link ExtensionModel} for the given plugin.
   *
   * @return {@link ExtensionModel} for the plugin or {@link Optional#empty()} if the plugin doesn't have an
   *         {@link ExtensionModel}.
   */
  Optional<LoadedExtensionInformation> loadExtensionData(File pluginJarFile);

  /**
   * Loads the {@link ExtensionModel} for a plugin defined by the {@link BundleDescriptor}. The artifact should be accessible by
   * Maven and the configuration defined for the {@link org.mule.tooling.client.api.ToolingRuntimeClient}.
   *
   * @param pluginDescriptor descriptor that defines the coordinates of the plugin.
   * @return {@link ExtensionModel} for the plugin or {@link Optional#empty()} if the plugin doesn't have an
   *         {@link ExtensionModel}.
   */
  Optional<LoadedExtensionInformation> loadExtensionData(BundleDescriptor pluginDescriptor);

  /**
   * Loads the {@link ExtensionModel} for Mule Runtime core components.
   *
   * @return {@link ExtensionModel} for Mule Runtime core components.
   */
  List<ExtensionModel> loadRuntimeExtensionModels();

  /**
   * Loads the {@link ArtifactPluginDescriptor} for the given plugin.
   *
   * @param pluginFile {@link File} referencing to the plugin artifact file (packaged or exploded).
   * @return {@link BundleDescriptor} for the plugin.
   */
  BundleDescriptor readBundleDescriptor(File pluginFile);

  /**
   * Loads the {@link ExtensionModel} for the given {@link ArtifactClassLoader} list and the dependent plugins
   * {@link ArtifactClassLoader}.
   *
   * @param artifactClassLoader        the plugin {@link ArtifactClassLoader} to resolve its {@link ExtensionModel}.
   * @param artifactPluginClassLoaders the context with all the dependent plugin {@link ArtifactClassLoader}.
   * @return {@link ExtensionModel} for the plugins defined in the list of {@link ArtifactClassLoader}.
   */
  Optional<LoadedExtensionInformation> loadExtensionData(ArtifactClassLoader artifactClassLoader,
                                                         List<ArtifactClassLoader> artifactPluginClassLoaders);
}

==> mule-runtime-tooling-client-4.5.0-20220922-sources.jar: org/mule/tooling/client/internal/InternalExtensionModelService.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.tooling.client.internal;

import org.mule.maven.client.api.model.BundleDescriptor;
import org.mule.runtime.api.meta.model.ExtensionModel;
import org.mule.runtime.deployment.model.api.plugin.ArtifactPluginDescriptor;
import org.mule.runtime.module.artifact.api.classloader.ArtifactClassLoader;

import java.io.File;
import java.util.List;
import java.util.Optional;

public interface InternalExtensionModelService {

  /**
   * Loads the {@link ExtensionModel} for the given plugin.
   *
   * @return {@link ExtensionModel} for the plugin or {@link Optional#empty()} if the plugin doesn't have an
   *         {@link ExtensionModel}.
   */
  Optional<LoadedExtensionInformation> loadExtensionData(File pluginJarFile);

  /**
   * Loads the {@link ExtensionModel} for a plugin defined by the {@link BundleDescriptor}. The artifact should be accessible by
   * Maven and the configuration defined for the {@link org.mule.tooling.client.api.ToolingRuntimeClient}.
   *
   * @param pluginDescriptor descriptor that defines the coordinates of the plugin.
   * @return {@link ExtensionModel} for the plugin or {@link Optional#empty()} if the plugin doesn't have an
   *         {@link ExtensionModel}.
   */
  Optional<LoadedExtensionInformation> loadExtensionData(BundleDescriptor pluginDescriptor);

  /**
   * Loads the {@link ExtensionModel} for Mule Runtime core components.
   *
   * @return {@link ExtensionModel} for Mule Runtime core components.
   */
  List<ExtensionModel> loadRuntimeExtensionModels();

  /**
   * Loads the {@link ArtifactPluginDescriptor} for the given plugin.
   *
   * @param pluginFile {@link File} referencing to the plugin artifact file (packaged or exploded).
   * @return {@link BundleDescriptor} for the plugin.
   */
  BundleDescriptor readBundleDescriptor(File pluginFile);

  /**
   * Loads the {@link ExtensionModel} for the given {@link ArtifactClassLoader} list and the dependent plugins
   * {@link ArtifactClassLoader}.
   *
   * @param artifactClassLoader        the plugin {@link ArtifactClassLoader} to resolve its {@link ExtensionModel}.
   * @param artifactPluginClassLoaders the context with all the dependent plugin {@link ArtifactClassLoader}.
   * @return {@link ExtensionModel} for the plugins defined in the list of {@link ArtifactClassLoader}.
   */
  Optional<LoadedExtensionInformation> loadExtensionData(ArtifactClassLoader artifactClassLoader,
                                                         List<ArtifactClassLoader> artifactPluginClassLoaders);
}
